VfsFileSystem

Enum VfsFileSystem 

pub enum VfsFileSystem {
Show 13 variants Apm(ApmFileSystem), Ext(ExtFileSystem), Ewf(EwfFileSystem), Fake(FakeFileSystem), Gpt(GptFileSystem), Mbr(MbrFileSystem), Ntfs(NtfsFileSystem), Os, Qcow(QcowFileSystem), SparseImage(SparseImageFileSystem), Udif(UdifFileSystem), Vhd(VhdFileSystem), Vhdx(VhdxFileSystem),
}
Virtual File System (VFS) file system.

Variants



Apm(ApmFileSystem)



Ext(ExtFileSystem)



Ewf(EwfFileSystem)



Fake(FakeFileSystem)



Gpt(GptFileSystem)



Mbr(MbrFileSystem)



Ntfs(NtfsFileSystem)



Os



Qcow(QcowFileSystem)



SparseImage(SparseImageFileSystem)



Udif(UdifFileSystem)



Vhd(VhdFileSystem)



Vhdx(VhdxFileSystem)

Implementations

Source

impl VfsFileSystem

pub fn new(location_type: &VfsType) -> Self

Creates a new file system.

pub fn file_entry_exists(&self, vfs_path: &VfsPath) -> Result<bool, ErrorTrace>

Determines if the file entry with the specified path exists.

pub fn get_data_stream_by_path_and_name( &self, vfs_path: &VfsPath, name: Option<&str>, ) -> Result<Option<DataStreamReference>, ErrorTrace>

Retrieves a data stream with the specified path and name.

pub fn get_file_entry_by_path( &self, vfs_path: &VfsPath, ) -> Result<Option<VfsFileEntry>, ErrorTrace>

Retrieves a file entry with the specified path.

pub fn get_root_file_entry(&self) -> Result<Option<VfsFileEntry>, ErrorTrace>

Retrieves the root file entry.